# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# Members cannot be deleted from the root unit.
FAILEDOPERATION_DISABLEDELETEMEMBERFROMROOTNODE = 'FailedOperation.DisableDeleteMemberFromRootNode'

# You cannot quit an organization created by yourself.
FAILEDOPERATION_DISABLEQUITSELFCREATEDORGANIZATION = 'FailedOperation.DisableQuitSelfCreatedOrganization'

# You are already in this organization.
FAILEDOPERATION_INORGANIZATIONALREADY = 'FailedOperation.InOrganizationAlready'

# The name is already in use.
FAILEDOPERATION_MEMBERNAMEUSED = 'FailedOperation.MemberNameUsed'

# There are members in this organizational unit.
FAILEDOPERATION_NODENOTEMPTY = 'FailedOperation.NodeNotEmpty'

# The organization already exists.
FAILEDOPERATION_ORGANIZATIONEXISTALREADY = 'FailedOperation.OrganizationExistAlready'

# There are members in this organization.
FAILEDOPERATION_ORGANIZATIONNOTEMPTY = 'FailedOperation.OrganizationNotEmpty'

# The invitation has already been sent before.
FAILEDOPERATION_RESENTINVITATION = 'FailedOperation.ReSentInvitation'

# A UIN does not belong to this organization.
FAILEDOPERATION_SOMEUINSNOTINORGANIZATION = 'FailedOperation.SomeUinsNotInOrganization'

# The user has already joined the organization.
FAILEDOPERATION_USERINORGANIZATION = 'FailedOperation.UserInOrganization'

# The account that sent the invitation is not a primary account.
FAILEDOPERATION_USERNOTREGISTER = 'FailedOperation.UserNotRegister'

# The number of organization members has reached the maximum.
LIMITEXCEEDED_MEMBERS = 'LimitExceeded.Members'

# Too many organizational unit levels.
LIMITEXCEEDED_NODEDEPTHEXCEEDLIMIT = 'LimitExceeded.NodeDepthExceedLimit'

# The number of organizational units has reached the upper limit.
LIMITEXCEEDED_NODEEXCEEDLIMIT = 'LimitExceeded.NodeExceedLimit'

# The organizational unit name is already in use.
RESOURCEINUSE_NODENAME = 'ResourceInUse.NodeName'

# This name is already in use.
RESOURCEINUSE_NODENAMEUSED = 'ResourceInUse.NodeNameUsed'

# The invitation information does not exist.
RESOURCENOTFOUND_INVITATIONNOTEXIST = 'ResourceNotFound.InvitationNotExist'

# The member does not exist.
RESOURCENOTFOUND_MEMBERNOTEXIST = 'ResourceNotFound.MemberNotExist'

# The organizational unit does not exist.
RESOURCENOTFOUND_NODENOTEXIST = 'ResourceNotFound.NodeNotExist'

# The organization does not exist.
RESOURCENOTFOUND_ORGANIZATIONNOTEXIST = 'ResourceNotFound.OrganizationNotExist'

# The user does not exist.
RESOURCENOTFOUND_USERNOTEXIST = 'ResourceNotFound.UserNotExist'
