# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# File download failed.
FAILEDOPERATION_DOWNLOADERROR = 'FailedOperation.DownLoadError'

# The image is empty.
FAILEDOPERATION_EMPTYIMAGEERROR = 'FailedOperation.EmptyImageError'

# Recognition by the engine timed out.
FAILEDOPERATION_ENGINERECOGNIZETIMEOUT = 'FailedOperation.EngineRecognizeTimeout'

# The image is blurry.
FAILEDOPERATION_IMAGEBLUR = 'FailedOperation.ImageBlur'

# Image decoding failed.
FAILEDOPERATION_IMAGEDECODEFAILED = 'FailedOperation.ImageDecodeFailed'

# No text is detected in the image.
FAILEDOPERATION_IMAGENOTEXT = 'FailedOperation.ImageNoText'

# The image is too large. Please see the description of image size limit in the output parameters.
FAILEDOPERATION_IMAGESIZETOOLARGE = 'FailedOperation.ImageSizeTooLarge'

# The input language is not supported.
FAILEDOPERATION_LANGUAGENOTSUPPORT = 'FailedOperation.LanguageNotSupport'

# Not a Hong Kong identity card.
FAILEDOPERATION_NOHKIDCARD = 'FailedOperation.NoHKIDCard'

# Not a passport.
FAILEDOPERATION_NOPASSPORT = 'FailedOperation.NoPassport'

# OCR failed.
FAILEDOPERATION_OCRFAILED = 'FailedOperation.OcrFailed'

# Unknown error.
FAILEDOPERATION_UNKNOWERROR = 'FailedOperation.UnKnowError'

# The service is not activated.
FAILEDOPERATION_UNOPENERROR = 'FailedOperation.UnOpenError'

# Image decoding failed.
INVALIDPARAMETER_ENGINEIMAGEDECODEFAILED = 'InvalidParameter.EngineImageDecodeFailed'

# Incorrect parameter value.
INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUELIMIT = 'InvalidParameterValue.InvalidParameterValueLimit'

# The file is too large.
LIMITEXCEEDED_TOOLARGEFILEERROR = 'LimitExceeded.TooLargeFileError'

# Exceptional billing status.
RESOURCESSOLDOUT_CHARGESTATUSEXCEPTION = 'ResourcesSoldOut.ChargeStatusException'
