# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# The account already exists in the account group.
FAILEDOPERATION_ACCOUNTALREADYEXISTEDINACCOUNTGROUP = 'FailedOperation.AccountAlreadyExistedInAccountGroup'

# The account group name already exists.
FAILEDOPERATION_ACCOUNTGROUPNAMEEXISTED = 'FailedOperation.AccountGroupNameExisted'

# The account group does not exist
FAILEDOPERATION_ACCOUNTGROUPNOTEXISTED = 'FailedOperation.AccountGroupNotExisted'

# The account ID list cannot be empty.
FAILEDOPERATION_ACCOUNTIDSISNULL = 'FailedOperation.AccountIdsIsNull'

# The account name already exists.
FAILEDOPERATION_ACCOUNTNAMEEXISTED = 'FailedOperation.AccountNameExisted'

# The account does not exist.
FAILEDOPERATION_ACCOUNTNOTEXISTED = 'FailedOperation.AccountNotExisted'

# An exception occurred while adding the user to the user group.
FAILEDOPERATION_ADDUSERSTOUSERGROUP = 'FailedOperation.AddUsersToUserGroup'

# The application ID cannot be empty.
FAILEDOPERATION_APPIDISNULL = 'FailedOperation.AppIdIsNull'

# The application ID does not exist.
FAILEDOPERATION_APPIDNOTFOUND = 'FailedOperation.AppIdNotFound'

# 
FAILEDOPERATION_APPNOTEXIST = 'FailedOperation.AppNotExist'

# 
FAILEDOPERATION_CHILDORGNODENAMEALREADYEXISTS = 'FailedOperation.ChildOrgNodeNameAlreadyExists'

# Organization nodes where sub-organizations have users cannot be deleted.
FAILEDOPERATION_CHILDORGNODEWITHUSERSCANNOTBEDELETED = 'FailedOperation.ChildOrgNodeWithUsersCanNotBeDeleted'

# 
FAILEDOPERATION_CREATEORGNODEERROR = 'FailedOperation.CreateOrgNodeError'

# An exception occurred while creating the user.
FAILEDOPERATION_CREATEUSERFAILURE = 'FailedOperation.CreateUserFailure'

# An exception occurred while creating the user group.
FAILEDOPERATION_CREATEUSERGROUPFAILURE = 'FailedOperation.CreateUserGroupFailure'

# 
FAILEDOPERATION_CUSTOMIZEPARENTORGNODEIDALREADYEXISTS = 'FailedOperation.CustomizeParentOrgNodeIdAlreadyExists'

# 
FAILEDOPERATION_CUSTOMIZEDORGNODEIDCANNOTBEEMPTY = 'FailedOperation.CustomizedOrgNodeIdCanNotBeEmpty'

# 
FAILEDOPERATION_DEFAULTORGNODECANNOTBEDELETED = 'FailedOperation.DefaultOrgNodeCanNotBeDeleted'

# 
FAILEDOPERATION_DELETEORGNODEERROR = 'FailedOperation.DeleteOrgNodeError'

# The user is an admin and cannot be deleted.
FAILEDOPERATION_DELETEUSEREXISTSADMINISTRATOR = 'FailedOperation.DeleteUserExistsAdministrator'

# Failed to delete the user.
FAILEDOPERATION_DELETEUSERFAILURE = 'FailedOperation.DeleteUserFailure'

# An exception occurred while deleting the user group.
FAILEDOPERATION_DELETEUSERGROUPFAILURE = 'FailedOperation.DeleteUserGroupFailure'

# 
FAILEDOPERATION_DESCRIBEORGNODEERROR = 'FailedOperation.DescribeOrgNodeError'

# 
FAILEDOPERATION_DESCRIBEORGNODEROOTERROR = 'FailedOperation.DescribeOrgNodeRootError'

# The value of `EntityType` is invalid.
FAILEDOPERATION_ENTITYTYPENOTEXISTED = 'FailedOperation.EntityTypeNotExisted'

# The user attribute type expected to be returned does not exist.
FAILEDOPERATION_EXPECTFIELDSNOTFOUND = 'FailedOperation.ExpectFieldsNotFound'

# The user group ID was not found.
FAILEDOPERATION_GROUPIDNOTFOUND = 'FailedOperation.GroupIdNotFound'

# 
FAILEDOPERATION_IDTOCODEERROR = 'FailedOperation.IdToCodeError'

# The number of data entries exceeds the upper limit.
FAILEDOPERATION_ITEMSEXCEEDMAXNUMBER = 'FailedOperation.ItemsExceedMaxNumber'

# You cannot add more than %s mappings for the same user in the same application.
FAILEDOPERATION_LIMITQUOTANOTENOUGH = 'FailedOperation.LimitQuotaNotEnough'

# 
FAILEDOPERATION_LISTUSERGROUPSOFUSERERROR = 'FailedOperation.ListUserGroupsOfUserError'

# 
FAILEDOPERATION_LISTUSERSINORGNODEERROR = 'FailedOperation.ListUsersInOrgNodeError'

# 
FAILEDOPERATION_LISTUSERSINUSERGROUPERROR = 'FailedOperation.ListUsersInUserGroupError'

# The primary organization does not exist.
FAILEDOPERATION_MAINORGNODENOTEXIST = 'FailedOperation.MainOrgNodeNotExist'

# The new password cannot be empty.
FAILEDOPERATION_NEWPASSWORDMUSTNOTBLANK = 'FailedOperation.NewPasswordMustNotBlank'

# 
FAILEDOPERATION_OPERATIONERROR = 'FailedOperation.OperationError'

# The operation failed.
FAILEDOPERATION_OPERATIONFAILURE = 'FailedOperation.OperationFailure'

# The organization node ID does not exist.
FAILEDOPERATION_ORGNODEIDNOTEXIST = 'FailedOperation.OrgNodeIdNotExist'

# The organization node does not exist.
FAILEDOPERATION_ORGNODENOTEXIST = 'FailedOperation.OrgNodeNotExist'

# The root organization node cannot be deleted.
FAILEDOPERATION_ORGNODEROOTCANNOTBEDELETED = 'FailedOperation.OrgNodeRootCanNotBeDeleted'

# 
FAILEDOPERATION_ORGNODESETTINGERROR = 'FailedOperation.OrgNodeSettingError'

# Organization nodes with users cannot be deleted.
FAILEDOPERATION_ORGNODEWITHUSERSCANNOTBEDELETED = 'FailedOperation.OrgNodeWithUsersCanNotBeDeleted'

# The parent organization node ID was not found.
FAILEDOPERATION_PARENTORGNODEIDNOTFOUND = 'FailedOperation.ParentOrgNodeIdNotFound'

# The identity entity was not found.
FAILEDOPERATION_PERSONNOTFOUND = 'FailedOperation.PersonNotFound'

# 
FAILEDOPERATION_REMOVEUSERSFROMUSERGROUPERROR = 'FailedOperation.RemoveUsersFromUserGroupError'

# 
FAILEDOPERATION_SECONDARYORGNODEDUPLICATES = 'FailedOperation.SecondaryOrgNodeDuplicates'

# You cannot move users imported from LDAP to an organization not in the directory.
FAILEDOPERATION_UPDATELDAPUSERORGEXCEEDSRANGE = 'FailedOperation.UpdateLDAPUserOrgExceedsRange'

# 
FAILEDOPERATION_UPDATELDAPUSERORGNOTINSAMECROP = 'FailedOperation.UpdateLDAPUserOrgNotInSameCrop'

# You cannot move users created by the admin to an organization with the sync operation type.
FAILEDOPERATION_UPDATEUSEREXCEEDSRANGE = 'FailedOperation.UpdateUserExceedsRange'

# You cannot move WeCom users to an organization outside your enterprise.
FAILEDOPERATION_UPDATEWECOMUSERORGEXCEEDSRANGE = 'FailedOperation.UpdateWeComUserOrgExceedsRange'

# You cannot move WeCom users to a different enterprise organization.
FAILEDOPERATION_UPDATEWECOMUSERORGNOTINSAMECROP = 'FailedOperation.UpdateWeComUserOrgNotInSameCrop'

# The user already exists in the user group.
FAILEDOPERATION_USERALREADYEXISTEDINUSERGROUP = 'FailedOperation.UserAlreadyExistedInUserGroup'

# 
FAILEDOPERATION_USERAUTHLISTERROR = 'FailedOperation.UserAuthListError'

# The user's email address already exists.
FAILEDOPERATION_USEREMAILEXISTED = 'FailedOperation.UserEmailExisted'

# The user group does not exist.
FAILEDOPERATION_USERGROUPNOTEXIST = 'FailedOperation.UserGroupNotExist'

# 
FAILEDOPERATION_USERNAMEALREADYEXISTS = 'FailedOperation.UserNameAlreadyExists'

# 
FAILEDOPERATION_USERNOTEXISTINUSERGROUP = 'FailedOperation.UserNotExistInUserGroup'

# The user does not exist.
FAILEDOPERATION_USERNOTFOUND = 'FailedOperation.UserNotFound'

# 
FAILEDOPERATION_USERPHONEALREADYEXISTS = 'FailedOperation.UserPhoneAlreadyExists'

# The user's mobile number cannot be empty.
FAILEDOPERATION_USERPHONEISEMPTY = 'FailedOperation.UserPhoneIsEmpty'

# The application name already exists.
INVALIDPARAMETER_APPDISPLAYNAMEEXISTED = 'InvalidParameter.AppDisplayNameExisted'

# 
INVALIDPARAMETER_ATTRIBUTEVALUEVALIDERROR = 'InvalidParameter.AttributeValueValidError'

# 
INVALIDPARAMETER_ORGCODEILLEGAL = 'InvalidParameter.OrgCodeIllegal'

# The parameter is invalid.
INVALIDPARAMETER_PARAMETERILLEGAL = 'InvalidParameter.ParameterIllegal'

# The parameter is invalid.
INVALIDPARAMETER_PARAMETERLLLEGAL = 'InvalidParameter.Parameterlllegal'

# 
INVALIDPARAMETER_SEARCHCRITERIAILLEGAL = 'InvalidParameter.SearchCriteriaIllegal'

# 
INVALIDPARAMETER_TIMEFORMATILLEGAL = 'InvalidParameter.TimeFormatIllegal'

# 
INVALIDPARAMETER_USEREXPIRATIONTIMEILLEGAL = 'InvalidParameter.UserExpirationTimeIllegal'

# The user ID parameter is empty.
INVALIDPARAMETER_USERIDISNULL = 'InvalidParameter.UserIDIsNull'

# 
INVALIDPARAMETER_USERINFOSORTKEYISILLEGAL = 'InvalidParameter.UserInfoSortKeyIsIllegal'

# The username parameter is empty.
INVALIDPARAMETER_USERNAMEISNULL = 'InvalidParameter.UserNameIsNull'

# 
INVALIDPARAMETERVALUE_PARAMETERILLEGAL = 'InvalidParameterValue.ParameterIllegal'

# 
INVALIDPARAMETERVALUE_USERIDCANNOTBEEMPTY = 'InvalidParameterValue.UserIdCanNotBeEmpty'

# 
INVALIDPARAMETERVALUE_USERNAMECANNOTBEEMPTY = 'InvalidParameterValue.UserNameCanNotBeEmpty'

# 
LIMITEXCEEDED_PARAMETERLENGTHLIMITEXCEEDED = 'LimitExceeded.ParameterLengthLimitExceeded'

# 
LIMITEXCEEDED_SECONDARYNODECOUNTLIMITEXCEEDED = 'LimitExceeded.SecondaryNodeCountLimitExceeded'
