# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# Operation not allowed as your account is in arrears.
FAILEDOPERATION_USERFEENEGATIVE = 'FailedOperation.UserFeeNegative'

# Internal error.
INTERNALERROR = 'InternalError'

# Incorrect parameter.
INVALIDPARAMETER = 'InvalidParameter'

# Incorrect callback URL.
INVALIDPARAMETER_CALLBACKADDRESS = 'InvalidParameter.CallbackAddress'

# Invalid date.
INVALIDPARAMETER_DATEINVALID = 'InvalidParameter.DateInvalid'

# Incorrect tag.
INVALIDPARAMETER_TAGKEY = 'InvalidParameter.TagKey'

# Incorrect query time range.
INVALIDPARAMETER_TIMERANGEERROR = 'InvalidParameter.TimeRangeError'

# The number of created applications has reached the upper limit.
LIMITEXCEEDED_APPLICATION = 'LimitExceeded.Application'

# Missing parameter.
MISSINGPARAMETER = 'MissingParameter'

# Operation denied.
OPERATIONDENIED = 'OperationDenied'

# The resource does not exist.
RESOURCENOTFOUND = 'ResourceNotFound'

# Incorrect application ID.
RESOURCENOTFOUND_BIZIDISNOTFOUND = 'ResourceNotFound.BizidIsNotFound'

# The resource is unavailable
RESOURCEUNAVAILABLE = 'ResourceUnavailable'

# Unauthorized operation
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'

# Application creation is not authorized.
UNAUTHORIZEDOPERATION_CREATEAPPDENIED = 'UnauthorizedOperation.CreateAppDenied'

# Unverified user.
UNAUTHORIZEDOPERATION_UNREALNAMEAUTH = 'UnauthorizedOperation.UnRealNameAuth'

# Unknown parameter.
UNKNOWNPARAMETER = 'UnknownParameter'

# Operation unsupported.
UNSUPPORTEDOPERATION = 'UnsupportedOperation'
