# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# COS exception.
INTERNALERROR_INTERNALCOSERROR = 'InternalError.InternalCOSError'

# Database service exception.
INTERNALERROR_INTERNALDBERROR = 'InternalError.InternalDBError'

# Encryption service exception.
INTERNALERROR_INTERNALENCRYPTERROR = 'InternalError.InternalEncryptError'

# Format of the sender name is incorrect.
INVALIDPARAMETER_INVALIDFROMNAMEMALFORMED = 'InvalidParameter.InvalidFromNameMalformed'

# Format of the HTML email body is incorrect.
INVALIDPARAMETER_INVALIDHTMLCONTENTMALFORMED = 'InvalidParameter.InvalidHtmlContentMalformed'

# Format of the email address is incorrect.
INVALIDPARAMETER_INVALIDMAILADDRESSNAMEMALFORMED = 'InvalidParameter.InvalidMailAddressNameMalformed'

# Format of the email body is incorrect.
INVALIDPARAMETER_INVALIDMAILCONTENTMALFORMED = 'InvalidParameter.InvalidMailContentMalformed'

# Format of the recipient address is incorrect.
INVALIDPARAMETER_INVALIDRECEIVERNAMEMALFORMED = 'InvalidParameter.InvalidReceiverNameMalformed'

# Format of the summary is incorrect.
INVALIDPARAMETER_INVALIDSUBJECTMALFORMED = 'InvalidParameter.InvalidSubjectMalformed'

# Format of the email task name is incorrect.
INVALIDPARAMETER_INVALIDTASKNAMEMALFORMED = 'InvalidParameter.InvalidTaskNameMalformed'

# Format of the email body set in the template is incorrect.
INVALIDPARAMETER_INVALIDTEMPLATECONTENTMALFORMED = 'InvalidParameter.InvalidTemplateContentMalformed'

# Format of the template name is incorrect.
INVALIDPARAMETER_INVALIDTEMPLATENAMEMALFORMED = 'InvalidParameter.InvalidTemplateNameMalformed'

# Format of the template variable values is incorrect.
INVALIDPARAMETER_INVALIDTEMPLATEVALUEMALFORMED = 'InvalidParameter.InvalidTemplateValueMalformed'

# Format of the plain-text email body is incorrect.
INVALIDPARAMETER_INVALIDTEXTCONTENTMALFORMED = 'InvalidParameter.InvalidTextContentMalformed'

# The email task name already exists.
RESOURCEINUSE_INVALIDTASKNAMEDUPLICATE = 'ResourceInUse.InvalidTaskNameDuplicate'

# The email address does not exist.
RESOURCENOTFOUND_INVALIDMAILADDRESSNOTFOUND = 'ResourceNotFound.InvalidMailAddressNotFound'

# The recipient address does not exist.
RESOURCENOTFOUND_INVALIDRECEIVERNOTFOUND = 'ResourceNotFound.InvalidReceiverNotFound'

# The reply-to address does not exist.
RESOURCENOTFOUND_INVALIDREPLYNOTFOUND = 'ResourceNotFound.InvalidReplyNotFound'

# The email task does not exist.
RESOURCENOTFOUND_INVALIDTASKNAMENOTFOUND = 'ResourceNotFound.InvalidTaskNameNotFound'

# The template does not exist.
RESOURCENOTFOUND_INVALIDTEMPLATENOTFOUND = 'ResourceNotFound.InvalidTemplateNotFound'
