# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# Internal error.
INTERNALERROR = 'InternalError'

# Invalid `ActionType`.
INVALIDPARAMETER_ACTIONTYPE = 'InvalidParameter.ActionType'

# Incorrect authentication configuration.
INVALIDPARAMETER_AUTHINFO = 'InvalidParameter.AuthInfo'

# Invalid `CacheInfo` value
INVALIDPARAMETER_CACHEINFO = 'InvalidParameter.CacheInfo'

# Invalid CDN playback domain name.
INVALIDPARAMETER_CDNDOMAIN = 'InvalidParameter.CdnDomain'

# Invalid `ChannelId`.
INVALIDPARAMETER_CHANNELID = 'InvalidParameter.ChannelId'

# The quantity exceeds the limit.
INVALIDPARAMETER_EXCEEDEDQUANTITYLIMIT = 'InvalidParameter.ExceededQuantityLimit'

# Invalid `Id`.
INVALIDPARAMETER_ID = 'InvalidParameter.Id'

# Invalid `LvbDomain`.
INVALIDPARAMETER_LVBDOMAIN = 'InvalidParameter.LvbDomain'

# Invalid name.
INVALIDPARAMETER_NAME = 'InvalidParameter.Name'

# Failed to find the channel/input/output.
INVALIDPARAMETER_NOTFOUND = 'InvalidParameter.NotFound'

# Invalid `PageNum`.
INVALIDPARAMETER_PAGENUM = 'InvalidParameter.PageNum'

# Invalid `PageSize`.
INVALIDPARAMETER_PAGESIZE = 'InvalidParameter.PageSize'

# Invalid `Points` value
INVALIDPARAMETER_POINTS = 'InvalidParameter.Points'

# Invalid protocol.
INVALIDPARAMETER_PROTOCOL = 'InvalidParameter.Protocol'

# Invalid `Url`.
INVALIDPARAMETER_URL = 'InvalidParameter.Url'
